# vue-shufflejs-plugin

[![vue2](https://img.shields.io/badge/vue-2.x-brightgreen.svg)](https://vuejs.org/)

A [Vue.js](https://vuejs.org) plugin for [Shuffle.js](https://vestride.github.io/Shuffle/) library.  
**Note**: This project is still under development!

The plugin use and require the following packages:

* [Bootstrap 3](http://getbootstrap.com) - Grid system
* [vue-multiselect](https://vue-multiselect.js.org) - Probably the most complete selecting solution for Vue.js 2.0, without jQuery. ([Github](https://github.com/shentao/vue-multiselect))
* [imagesLoaded](http://imagesloaded.desandro.com) - Detect when images have been loaded. ([Github](https://github.com/desandro/imagesloaded))

## Documentation

- [Shuffle.js Docs](https://vestride.github.io/Shuffle/)

## Installation

The preferred way to install this extension is through [yarn](https://yarnpkg.com) or [npm](https://www.npmjs.com).

Either run 

```bash
yarn add https://git.hrzg.de/dmstr/vue-shufflejs-plugin.git#0.3.2
```
or via npm 

```bash
npm install https://git.hrzg.de/dmstr/vue-shufflejs-plugin.git#0.3.2 --save
```
## Usage

The following types are supported: 

- [Basic masonry layout](https://vestride.github.io/Shuffle/basic) without any extra options 
- Grid with [filter, search and / or sort options](https://vestride.github.io/Shuffle/)
- ...

The following example renders the [Shuffle.js](https://vestride.github.io/Shuffle/) plugin with Filter, Search and Sort `options`.  
Please check the [Shuffle.js](https://vestride.github.io/Shuffle/) documentation for available `options` supported by the plugin.

#### Bundler (Webpack, etc.)

```js
import Vue from 'vue'
import VueShuffle from 'vue-shufflejs-plugin'
// You need a specific loader for CSS files like https://github.com/webpack/css-loader
import 'vue-shufflejs-plugin/dist/vue-shufflejs-plugin.css'

Vue.use(VueShuffle)
```

###### Bootstrap icon font issue:

Add

```bash
yarn add url-loader --dev
```
or via npm 

```bash
npm install url-loader --save-dev
```
Updated module rules section in webpack config and add:

```js
{
  test: /\.(woff2?|eot|ttf|otf|svg)(\?.*)?$/,
  loader: 'url-loader'
}
```

#### Browser

```html
<!-- Include after Vue -->
<!-- Local files -->
<link rel="stylesheet" href="vue-shufflejs-plugin/dist/vue-shufflejs-plugin.css"></link>
<script src="vue-shufflejs-plugin/dist/vue-shufflejs-plugin.js"></script>
```

#### Use component in Vue app

```
import axios from 'axios'

export default {
  name: 'app',
  data () {
    return {
      settingsApiUrl: 'http://spiess-kuehne.ch.workbench.oneba.se/api/settings?internalDetailPath=1',
      settings: null,
      products: {
        data: null,
        option: null,
        filter: null
      }
    }
  },
  created () {
    axios.get(this.settingsApiUrl)
      .then((response) => {
        this.settings = response.data

        axios.get(this.settings.baseUrl + this.settings.endpoints.data)
          .then((response) => {
            this.products.data = response.data
          })
          .catch((error) => {
            console.error(error)
          })

        axios.get(this.settings.baseUrl + this.settings.endpoints.option)
          .then((response) => {
            this.products.option = response.data
          })
          .catch((error) => {
            console.error(error)
          })

        axios.get(this.settings.baseUrl + this.settings.endpoints.filter)
          .then((response) => {
            this.products.filter = response.data
          })
          .catch((error) => {
            console.error(error)
          })
      })
      .catch((error) => {
        console.error(error)
      })
  }
}
```
```html
<vue-shuffle :settings="settings" :products="products"></vue-shuffle>
```

###### Settings API response

```json
settings: {
  "baseUrl": "http://spiess-kuehne.ch.workbench.oneba.se",
  "imageApiPath": "/filefly/api?action=stream&path=",
  "imgBaseUrl": "http://img.workbench.oneba.se",
  "imgHostPrefix": "http://spiess-kuehne.ch.workbench.oneba.se/img/stream",
  "imgHostSuffix": ",p2",
  "detailPath": false, // or '/de/frontend/products/detail?productId='
  "endpoints": {
    "settings": "/api/settings",
    "data": "/api/product-data",
    "option": "/api/product-option",
    "filter": "/api/product-filter"
  },
  "languages": [
    "de",
    "en"
  ],
  "enabledFilter": true,
  "enabledFilterOptions": false,
  "filterMode": "and", // or "or", is ignored if "enabledFilterOptions" is set to false
  "enabledSearch": true,
  "enabledSort": true
}
```

## Tests

WIP!

## Devlopment

WIP!

```bash
# serve with hot reload at localhost:8080
yarn run dev

# distribution build with minification
yarn run build

# build the documentation into docs
yarn run docs

# run unit tests
yarn run test

# run unit tests watch
yarn run unit-watch
```

For detailed explanation on how things work, checkout the [guide](http://vuejs-templates.github.io/webpack/) and [docs for vue-loader](http://vuejs.github.io/vue-loader).

### Further Information

[Shuffle.js](https://vestride.github.io/Shuffle/) has lots of configuration options, please check the [Shuffle.js](https://vestride.github.io/Shuffle/) library website.

## Credits

* [Glen Cheney](https://github.com/Vestride) - [Shuffle.js](https://vestride.github.io/Shuffle/)
* [Damian Dulisz](https://github.com/shentao/vue-multiselect) -  [vue-multiselect](https://github.com/shentao/vue-multiselect)
* [David DeSandro](https://github.com/desandro) - [desandro/imagesloaded](http://imagesloaded.desandro.com)


## License

The MIT License (MIT). Please see [License File](./LICENSE.md) for more information.
